Documentation
¶
Overview ¶
Package gcerr provides an error type for Go CDK APIs.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrUnknown means that the error could not be categorized. ErrUnknown = errors.New("Unknown") // ErrNotFound means that the resource was not found. ErrNotFound = errors.New("NotFound") // ErrAlreadyExists means that the resource exists, but it should not. ErrAlreadyExists = errors.New("AlreadyExists") // ErrInvalidArgument means that a value given to a Go CDK API is incorrect. ErrInvalidArgument = errors.New("InvalidArgument") // ErrInternal means that something unexpected happened. Internal errors always indicate // bugs in the Go CDK (or possibly the underlying service). ErrInternal = errors.New("Internal") // ErrUnimplemented means that the feature is not implemented. ErrUnimplemented = errors.New("Unimplemented") // ErrFailedPrecondition means that the system was in the wrong state. ErrFailedPrecondition = errors.New("FailedPrecondition") // ErrPermissionDenied means that the caller does not have permission to execute the specified operation. ErrPermissionDenied = errors.New("PermissionDenied") // ErrResourceExhausted means that some resource has been exhausted, typically because a service resource limit // has been reached. ErrResourceExhausted = errors.New("ResourceExhausted") // ErrCanceled means that the operation was canceled. ErrCanceled = errors.New("Canceled") // ErrDeadlineExceeded means that The operation timed out. ErrDeadlineExceeded = errors.New("DeadlineExceeded") )
Functions ¶
func DoNotWrap ¶
DoNotWrap reports whether an error should not be wrapped in the Error type from this package. It returns true if err is a retry error, a context error, io.EOF, or if it wraps one of those.
Types ¶
type Error ¶
type Error struct {
// Code is the error code.
Code ErrorCode
// contains filtered or unexported fields
}
An Error describes a Go CDK error.
func New ¶
New returns a new error with the given code, underlying error and message. Pass 1 for the call depth if New is called from the function raising the error; pass 2 if it is called from a helper function that was invoked by the original function; and so on.
func (*Error) FormatError ¶
FormatError formats the errots.
type ErrorCode ¶
type ErrorCode int
An ErrorCode describes the error's category.
const ( // OK is returned by the Code function on a nil error. It is not a valid // code for an error. OK ErrorCode = 0 // Unknown means that the error could not be categorized. Unknown ErrorCode = 1 // NotFound means that the resource was not found. NotFound ErrorCode = 2 // AlreadyExists means that the resource exists, but it should not. AlreadyExists ErrorCode = 3 // InvalidArgument means that a value given to a Go CDK API is incorrect. InvalidArgument ErrorCode = 4 // Internal means that something unexpected happened. Internal errors always indicate // bugs in the Go CDK (or possibly the underlying service). Internal ErrorCode = 5 // Unimplemented means that the feature is not implemented. Unimplemented ErrorCode = 6 // FailedPrecondition means that the system was in the wrong state. FailedPrecondition ErrorCode = 7 // PermissionDenied means that the caller does not have permission to execute the specified operation. PermissionDenied ErrorCode = 8 // ResourceExhausted means that some resource has been exhausted, typically because a service resource limit // has been reached. ResourceExhausted ErrorCode = 9 // Canceled means that the operation was canceled. Canceled ErrorCode = 10 // DeadlineExceeded means that The operation timed out. DeadlineExceeded ErrorCode = 11 )
Click to show internal directories.
Click to hide internal directories.